defmodule Tradex.Application do
  # See https://hexdocs.pm/elixir/Application.html
  # for more information on OTP Applications
  @moduledoc false

  use Application

  @impl true
  def start(_type, _args) do
    children = [
      TradexWeb.Telemetry,
      Tradex.Repo,
      {DNSCluster, query: Application.get_env(:tradex, :dns_cluster_query) || :ignore},
      {Oban, Application.fetch_env!(:tradex, Oban)},
      {Phoenix.PubSub, name: Tradex.PubSub},
      # Start the Finch HTTP client for sending emails
      {Finch, name: Tradex.Finch},
      # Start a worker by calling: Tradex.Worker.start_link(arg)
      # {Tradex.Worker, arg},
      # Start to serve requests, typically the last entry
      TradexWeb.Endpoint
    ]

    # See https://hexdocs.pm/elixir/Supervisor.html
    # for other strategies and supported options
    opts = [strategy: :one_for_one, name: Tradex.Supervisor]
    Supervisor.start_link(children, opts)
  end

  # Tell Phoenix to update the endpoint configuration
  # whenever the application is updated.
  @impl true
  def config_change(changed, _new, removed) do
    TradexWeb.Endpoint.config_change(changed, removed)
    :ok
  end
end
